<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pt_BR">
<context>
    <name>MEConfig</name>
    <message>
        <location filename="../mainwindow.ui" line="26"/>
        <source>MX User Manager</source>
        <translation>MX Gerenciamento de usuários</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="62"/>
        <source>Administration</source>
        <translation>Administração</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="65"/>
        <source>Add a new user</source>
        <translation>Adicionar novo usuário</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="105"/>
        <source>Add User Account</source>
        <translation>Adicionar conta de utilizador</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="132"/>
        <source>Reenter password for new user</source>
        <translation>Reintroduzir a senha para o novo usuário</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="141"/>
        <source>confirm password</source>
        <translation>confirmar a senha</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="154"/>
        <location filename="../mainwindow.ui" line="1118"/>
        <source>Username of new user</source>
        <translation>Nomedeusuario do novo usuário</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="157"/>
        <source>User login name:</source>
        <translation>Nome de acesso do usuário:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="170"/>
        <location filename="../mainwindow.ui" line="416"/>
        <location filename="../mainwindow.ui" line="1134"/>
        <source>Enter username of new user</source>
        <translation>Introduzir o nomedeusuario do novo usuário</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="176"/>
        <location filename="../mainwindow.ui" line="422"/>
        <source>username</source>
        <translation>nomedeusuario</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="189"/>
        <location filename="../mainwindow.ui" line="227"/>
        <source>Password for new user</source>
        <translation>Senha para o novo usuário</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="192"/>
        <source>User password:</source>
        <translation>Senha de usuário:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="205"/>
        <source>Enter password for new user</source>
        <translation>Introduzir a senha para o novo usuário</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="214"/>
        <source>password</source>
        <translation>senha</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="230"/>
        <source>Confirm user password:</source>
        <translation>Confirmar a senha do usuário:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="262"/>
        <source>Delete User Account</source>
        <translation>Eliminar a conta de utilizador</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="305"/>
        <source>Select user</source>
        <translation>Selecionar usuário</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="321"/>
        <location filename="../mainwindow.ui" line="1209"/>
        <location filename="../mainwindow.ui" line="1222"/>
        <location filename="../mainwindow.ui" line="1346"/>
        <location filename="../mainwindow.ui" line="1368"/>
        <source>Select user to delete</source>
        <translation>Selecionar o usuário a eliminar</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="330"/>
        <source>User to delete:</source>
        <translation>Usuário a eliminar:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="343"/>
        <source>Also delete the user&apos;s home directory</source>
        <translation>Eliminar também a pasta pessoal do usuário</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="346"/>
        <source>Delete user home directory</source>
        <translation>Eliminar a pasta pessoal do usuário</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="359"/>
        <source>Rename User Account</source>
        <translation>Renomear Conta de Usuário</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="371"/>
        <location filename="../mainwindow.ui" line="483"/>
        <source>Select user to modify:</source>
        <translation>Selecionar o usuário a modificar:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="403"/>
        <source>New user name:</source>
        <translation>Nome do novo usuário:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="432"/>
        <source>Change User Password</source>
        <translation>Alterar a Senha de Usuário</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="447"/>
        <source>new password</source>
        <translation>nova senha</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="460"/>
        <source>Confirm new password:</source>
        <translation>Confirmar a nova senha:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="470"/>
        <source>confirm new password</source>
        <translation>confirmar a nova senha</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="496"/>
        <source>New user password:</source>
        <translation>Nova senha de usuário:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="527"/>
        <source>Options</source>
        <translation>Opções</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="530"/>
        <source>Repair a user configuration</source>
        <translation>Reparar uma configuração de usuário</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="564"/>
        <location filename="../mainwindow.ui" line="1271"/>
        <source>Modify User Account</source>
        <translation>Alterar Conta de Utilizador</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="576"/>
        <location filename="../mainwindow.ui" line="592"/>
        <source>Select user to repair</source>
        <translation>Selecionar usuário a reparar</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="579"/>
        <location filename="../mainwindow.ui" line="1355"/>
        <source>User to change:</source>
        <translation>Usuário a alterar:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="624"/>
        <source>Restore Defaults</source>
        <translation>Restaurar predefinições</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="645"/>
        <source>Restore browser configs to MX defaults</source>
        <translation>Restaurar as configurações do navegador para as pré-definições do MX</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="651"/>
        <source>Mozilla (Iceweasel or Firefox) configs</source>
        <translation>Configurações para Mozilla (Iceweasel ou Firefox)</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="654"/>
        <source>Alt+X</source>
        <translation>Alt+X</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="661"/>
        <source>Restore group memberships to MX defaults</source>
        <translation>Restaurar a pertença a grupos para as pré-definições do MX</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="667"/>
        <source>Group memberships</source>
        <translation>Pertença a grupos</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="670"/>
        <source>Alt+G</source>
        <translation>Alt+G</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="680"/>
        <source>Change Autologin Settings</source>
        <translation>Alterar as configurações de Acesso Automático</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="686"/>
        <source>Log in automatically</source>
        <translation>Iniciar sessão automaticamente</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="693"/>
        <source>Require password to log in</source>
        <translation>Requerer senha para iniciar sessão</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="708"/>
        <source>Copy/Sync</source>
        <translation>Copiar/Sincronizar</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="735"/>
        <source>Copy Between Desktops</source>
        <translation>Copiar entre Ambientes de Trabalho</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="762"/>
        <location filename="../mainwindow.ui" line="829"/>
        <source>Select desktop to copy from</source>
        <translation>Selecionar o ambiente de trabalho de onde copiar</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="775"/>
        <source>Select to only copy files</source>
        <translation>Selecionar para apenas copiar ficheiros</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="778"/>
        <source>Copy only</source>
        <translation>Apenas copiar</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="794"/>
        <location filename="../mainwindow.ui" line="807"/>
        <source>Select desktop to copy to</source>
        <translation>Selecionar o ambiente de trabalho para onde copiar</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="816"/>
        <source>Copy to:</source>
        <translation>Copiar para:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="838"/>
        <source>Copy from:</source>
        <translation>Copiar de:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="851"/>
        <source>Select to copy and then delete differences</source>
        <translation>Selecionar para copiar e de seguida eliminar diferenças</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="854"/>
        <source>Sync</source>
        <translation>Sincronizar</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="900"/>
        <source>Select to copy/sync Shared</source>
        <translation>Selecionar para copiar/sincronizar Partilhado</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="903"/>
        <source>Shared folder</source>
        <translation>Pasta Partilhas</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="916"/>
        <source>Select to copy/sync entire home</source>
        <translation>Selecionar para copiar/sincronizar toda a pasta pessoal</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="919"/>
        <source>Entire home</source>
        <translation>Toda a pasta pessoal</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="935"/>
        <source>Select to copy/sync the browser configuration</source>
        <translation>Selecionar para copiar/sincronizar a configuração do navegador</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="938"/>
        <source>Mozilla (Firefox or Iceweasel) configs</source>
        <translation>Mozilla (Firefox ou Iceweasel) configs</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="951"/>
        <source>Select to copy/sync Documents</source>
        <translation>Selecionar para copiar/sincronizar a pasta Documentos</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="954"/>
        <source>Documents folder</source>
        <translation>Pasta Documentos</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="961"/>
        <source>What to copy/sync:</source>
        <translation>O que copiar/sincronizar:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="977"/>
        <source>Progress</source>
        <translation>Progresso</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1007"/>
        <location filename="../mainwindow.ui" line="1023"/>
        <source>Status of the changes</source>
        <translation>Estado das alterações</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1026"/>
        <source>Status:</source>
        <translation>Estado:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1042"/>
        <source>Progress of the changes</source>
        <translation>Progresso das alterações</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1079"/>
        <source>Add/Remove Groups</source>
        <translation>Adicionar/Remover grupos</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1091"/>
        <source>Add Group</source>
        <translation>Adicionar grupo</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1121"/>
        <source>Group name:</source>
        <translation>Nome de grupo:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1140"/>
        <source>groupname</source>
        <translation>nomedegrupo</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1169"/>
        <source>Delete Group</source>
        <translation>Eliminar grupo</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1231"/>
        <source>Group to delete:</source>
        <translation>Grupo a eliminar:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1259"/>
        <source>Group Membership</source>
        <translation>Pertença a grupo</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1375"/>
        <source>Groups user belongs to (change the groups by selecting/deselecting the appropriate boxes):</source>
        <translation>Grupos a que o usuário pertence (alterar os grupos marcando ou desmarcando as respectivas caixas):</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1395"/>
        <source>*Please doublecheck your selections before applying, assigning wrong group memberships can break your system.  Use Repair tab to restore the original memberships if you made a mistake.</source>
        <translation>*Verifique as escolhas antes de aplicar. Atribuir pertenças a grupos errados pode danificar o sistema. Se cometer algum erro, use o separador Reparar para restaurar as pertenças originais.</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1455"/>
        <source>Apply any changes</source>
        <translation>Aplicar alterações</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1458"/>
        <source>Apply</source>
        <translation>Aplicar</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1465"/>
        <source>Alt+A</source>
        <translation>Alt+A</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1472"/>
        <source>Cancel any changes then quit</source>
        <translation>Cancelar alterações e sair</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1475"/>
        <source>Close</source>
        <translation>Fechar</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1482"/>
        <source>Alt+N</source>
        <translation>Alt+N</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1523"/>
        <source>Display help </source>
        <translation>Exibir ajuda</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1526"/>
        <source>Help</source>
        <translation>Ajuda</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1533"/>
        <source>Alt+H</source>
        <translation>Alt+H</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1540"/>
        <source>About this application</source>
        <translation>Sobre esta aplicação</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1543"/>
        <source>About...</source>
        <translation>Sobre...</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1550"/>
        <source>Alt+B</source>
        <translation>Alt+B</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../mainwindow.cpp" line="109"/>
        <location filename="../mainwindow.cpp" line="141"/>
        <location filename="../mainwindow.cpp" line="149"/>
        <location filename="../mainwindow.cpp" line="162"/>
        <location filename="../mainwindow.cpp" line="173"/>
        <location filename="../mainwindow.cpp" line="182"/>
        <location filename="../mainwindow.cpp" line="191"/>
        <location filename="../mainwindow.cpp" line="634"/>
        <location filename="../mainwindow.cpp" line="651"/>
        <location filename="../mainwindow.cpp" line="682"/>
        <location filename="../mainwindow.cpp" line="691"/>
        <location filename="../mainwindow.cpp" line="836"/>
        <location filename="../mainwindow.cpp" line="949"/>
        <source>none</source>
        <translation>nenhum</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="203"/>
        <source>The user configuration will be repaired. Please close all other applications now. When finished, please logout or reboot. Are you sure you want to repair now?</source>
        <translation>A configuração de usuário será reparada. Feche todas as outras aplicações agora. Quando concluído, saia da sessão ou reinicie. Pretende fazer a reparação agora?</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="225"/>
        <source>User group membership was restored.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="232"/>
        <source>Mozilla settings were reset.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="242"/>
        <location filename="../mainwindow.cpp" line="258"/>
        <source>Autologin options</source>
        <translation>Opções de acesso automático</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="243"/>
        <source>Autologin has been disabled for the &apos;%1&apos; account.</source>
        <translation>O acesso automático foi desativado para  a conta &apos;%1&apos;.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="259"/>
        <source>Autologin has been enabled for the &apos;%1&apos; account.</source>
        <translation>O acesso automático foi ativado para  a conta &apos;%1&apos;.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="271"/>
        <source>You must specify a &apos;copy to&apos; destination. You cannot copy to the desktop you are logged in to.</source>
        <translation>Tem que especificar um destino para &apos;copiar para&apos;. Não pode copiar para o ambiente de trabalho da sessão.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="275"/>
        <source>Before copying, close all other applications. Be sure the copy to destination is large enough to contain the files you are copying. Copying between desktops may overwrite or delete your files or preferences on the destination desktop. Are you sure you want to proceed?</source>
        <translation>Antes de copiar, feche todas as outras aplicações. Certifique-se de que o destino de &apos;copiar para&apos; é suficientemente grande para receber todos os arquivos a copiar. Copiar entre ambientes de trabalho pode escrever por cima de, ou apagar, arquivos ou preferências no ambiente de trabalho de destino. Pretende continuar?</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="300"/>
        <source>Synchronizing desktop...</source>
        <translation>A sincronizar ambiente de trabalho...</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="302"/>
        <source>Copying desktop...</source>
        <translation>A copiar o ambiente de trabalho...</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="323"/>
        <location filename="../mainwindow.cpp" line="518"/>
        <source>The user name needs to be at least 2 characters long. Please select a longer name before proceeding.</source>
        <translation>O nome de usuário tem que ter pelo menos 2 caracteres. Escolha um nome de usuário mais comprido.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="327"/>
        <location filename="../mainwindow.cpp" line="522"/>
        <source>The user name needs to be lower case and it
cannot contain special characters or spaces.
Please choose another name before proceeding.</source>
        <translation>O nome de usuário tem que estar em minúsculas
e não pode conter caracteres especiais ou espaços.
Escolha outro nome de usuário.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="336"/>
        <source>Sorry, this name is in use. Please enter a different name.</source>
        <translation>Este nome já está em uso. Introduzir um nome diferente.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="341"/>
        <location filename="../mainwindow.cpp" line="376"/>
        <source>Password entries do not match. Please try again.</source>
        <translation>As senhas não coincidem. Tente de novo.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="346"/>
        <location filename="../mainwindow.cpp" line="381"/>
        <source>Password needs to be at least 2 characters long. Please enter a longer password before proceeding.</source>
        <translation>A senha tem que ter pelo menos 2 caracteres. Escolha uma senha mais longa.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="363"/>
        <source>The user was added ok.</source>
        <translation>O usuário foi adicionado.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="367"/>
        <source>Failed to add the user.</source>
        <translation>A adição do usuário falhou.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="395"/>
        <source>Password successfully changed.</source>
        <translation>A senha foi alterada.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="399"/>
        <source>Failed to change password.</source>
        <translation>Falha na alteração da senha.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="405"/>
        <source>This action cannot be undone. Are you sure you want to delete user %1?</source>
        <translation>Esta ação não pode ser revertida. Tem a certeza de que pretende eliminar o usuário %1?</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="418"/>
        <source>The user has been deleted.</source>
        <translation>O usuário foi eliminado.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="421"/>
        <source>Failed to delete the user.</source>
        <translation>A eliminação do usuário falhou.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="435"/>
        <source>The group name needs to be at least 2 characters long. Please select a longer name before proceeding.</source>
        <translation>O nome de grupo tem que ter pelo menos 2 caracteres. Escolha um nome mais comprido.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="439"/>
        <source>The group name needs to be lower case and it 
cannot contain special characters or spaces.
Please choose another name before proceeding.</source>
        <translation>O nome de grupo tem que estar em minúsculas
e não pode conter caracteres especiais ou espaços.
Escolha outro nome de usuário.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="448"/>
        <source>Sorry, that group name already exists. Please enter a different name.</source>
        <translation>Este nome de grupo já existe. Introduzir um nome diferente.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="455"/>
        <source>The system group was added ok.</source>
        <translation>O grupo foi addicionado.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="458"/>
        <source>Failed to add the system group.</source>
        <translation>A adição do grupo falhou.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="461"/>
        <source>This action cannot be undone. Are you sure you want to delete group %1?</source>
        <translation>Esta ação não pode ser revertida. Tem a certeza de que pretende eliminar o usuário %1?</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="468"/>
        <source>The group has been deleted.</source>
        <translation>O grupo foi eliminado.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="471"/>
        <source>Failed to delete the group.</source>
        <translation>A eliminação do grupo falhou.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="493"/>
        <source>The changes have been applied.</source>
        <translation>As alterações foram aplicadas.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="496"/>
        <source>Failed to apply group changes</source>
        <translation>A aplicação das alterações falhou</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="509"/>
        <source>The selected user name is currently in use.</source>
        <translation>O nome de usuário selecionado está presentemente em uso.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="510"/>
        <source>To rename this user, please log out and log back in using another user account.</source>
        <translation>Para renomear este usuário, saia da sessão e volte a entrar com outra conta de usuário.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="531"/>
        <source>Sorry, this name already exists on your system. Please enter a different name.</source>
        <translation>Este nome já existe no systema. Introduzir um nome diferente.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="539"/>
        <source>Failed to rename the user. Please make sure that the user is not logged in, you might need to restart</source>
        <translation>Falha ao renomear o usuário. Certifique-se de que o usuário não está em sessão; pode ser necessário reiniciar.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="560"/>
        <source>The user was renamed.</source>
        <translation>O usuário foi renomeado.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="573"/>
        <location filename="../mainwindow.cpp" line="602"/>
        <source>Synchronizing desktop...ok</source>
        <translation>A sincronizar ambiente de trabalho... concluído.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="575"/>
        <location filename="../mainwindow.cpp" line="604"/>
        <source>Copying desktop...ok</source>
        <translation>A copiar ambiente de trabalho... concluído.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="608"/>
        <source>Synchronizing desktop...failed</source>
        <translation>A sincronizar ambiente de trabalho... falhou</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="610"/>
        <source>Copying desktop...failed</source>
        <translation>A copiar ambiente de trabalho... falhou</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="628"/>
        <location filename="../mainwindow.cpp" line="888"/>
        <location filename="../mainwindow.cpp" line="896"/>
        <source>browse...</source>
        <translation>percorrer...</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="799"/>
        <source>About %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="800"/>
        <source>Version: </source>
        <translation>Versão: </translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="801"/>
        <source>Simple user configuration for MX Linux</source>
        <translation>Configuração simples de usuários para o Linux MX</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="803"/>
        <source>Copyright (c) MX Linux</source>
        <translation>Direitos de Autor (c) MX Linux</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="804"/>
        <source>%1 License</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="819"/>
        <source>%1 Help</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="889"/>
        <source>Select folder to copy to</source>
        <translation>Selecionar pasta para onde copiar</translation>
    </message>
</context>
<context>
    <name>QApplication</name>
    <message>
        <location filename="../about.cpp" line="32"/>
        <source>License</source>
        <translation>Licença</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="33"/>
        <location filename="../about.cpp" line="43"/>
        <source>Changelog</source>
        <translation>Relatório de alterações</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="34"/>
        <source>Cancel</source>
        <translation>Cancelar</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="51"/>
        <source>&amp;Close</source>
        <translation>&amp;Fechar</translation>
    </message>
    <message>
        <source>You must run this program as root.</source>
        <translation type="vanished">Tem que executar este programa como administrador (root).</translation>
    </message>
</context>
</TS>
